==> ginkgo-1.5.0_1+gcc12+mpich.darwin_10.ppc.tbz2: opt/local/lib/cmake/Ginkgo/GinkgoConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was GinkgoConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(GINKGO_PROJECT_NAME "Ginkgo")
set(GINKGO_PROJECT_VERSION 1.5.0)
set(GINKGO_PROJECT_DESCRIPTION "A numerical linear algebra library targeting many-core architectures")

# Extra version information
set(GINKGO_VERSION_MAJOR 1)
set(GINKGO_VERSION_MINOR 5)
set(GINKGO_VERSION_PATCH 0)

# Git information
set(GINKGO_GIT_BRANCH "")
set(GINKGO_GIT_REVISION "")
set(GINKGO_GIT_SHORTREV "")

# CMake build configuration
set(GINKGO_BUILD_TYPE "MacPorts")
set(GINKGO_BUILD_SHARED_LIBS "ON")
set(GINKGO_DEBUG_POSTFIX "d")

# Compiler configuration
set(GINKGO_CXX_COMPILER "/opt/local/bin/mpicxx-mpich-gcc12")
set(GINKGO_CXX_COMPILER_VERSION 12.2.0)

set(GINKGO_CXX_FLAGS "-pipe -Os -DNDEBUG -I/opt/local/include -D_GLIBCXX_USE_CXX11_ABI=0")
set(GINKGO_CXX_FLAGS_DEBUG "-g")
set(GINKGO_CXX_FLAGS_RELEASE "-O3 -DNDEBUG")

set(GINKGO_EXE_LINKER_FLAGS "-L/opt/local/lib -Wl,-headerpad_max_install_names -latomic -Wl,-rpath,/opt/local/lib/libgcc")
set(GINKGO_EXE_LINKER_FLAGS_DEBUG "")
set(GINKGO_EXE_LINKER_FLAGS_RELEASE "")

# Ginkgo configuration
set(GINKGO_BUILD_REFERENCE ON)
set(GINKGO_BUILD_OMP ON)
set(GINKGO_BUILD_CUDA OFF)
set(GINKGO_BUILD_HIP OFF)
set(GINKGO_BUILD_MPI ON)
set(GINKGO_BUILD_DPCPP OFF)

set(GINKGO_DEVEL_TOOLS OFF)
set(GINKGO_BUILD_TESTS ON)
set(GINKGO_BUILD_EXAMPLES OFF)
set(GINKGO_BUILD_EXTLIB_EXAMPLE )
set(GINKGO_BUILD_BENCHMARKS OFF)

set(GINKGO_BUILD_DOC OFF)
set(GINKGO_DOC_GENERATE_EXAMPLES OFF)
set(GINKGO_DOC_GENERATE_PDF OFF)
set(GINKGO_DOC_GENERATE_DEV )

set(GINKGO_SKIP_DEPENDENCY_UPDATE ON)
set(GINKGO_EXPORT_BUILD_DIR OFF)
set(GINKGO_VERBOSE_LEVEL 1)

set(GINKGO_WITH_CLANG_TIDY OFF)
set(GINKGO_WITH_IWYU OFF)
set(GINKGO_CLANG_TIDY_PATH )
set(GINKGO_IWYU_PATH )

set(GINKGO_JACOBI_FULL_OPTIMIZATIONS OFF)

set(GINKGO_CUDA_ARCHITECTURES Auto)
set(GINKGO_CUDA_DEFAULT_HOST_COMPILER OFF)
set(GINKGO_CUDA_HOST_COMPILER )
set(GINKGO_CUDA_ARCH_FLAGS )

set(GINKGO_HIP_COMPILER_FLAGS )
set(GINKGO_HIP_HCC_COMPILER_FLAGS )
set(GINKGO_HIP_NVCC_COMPILER_FLAGS )
set(GINKGO_HIP_CLANG_COMPILER_FLAGS )
set(GINKGO_HIP_PLATFORM )
set(GINKGO_HIP_PLATFORM_AMD_REGEX )
set(GINKGO_HIP_PLATFORM_NVIDIA_REGEX )
set(GINKGO_HIP_AMDGPU )
set(GINKGO_HIP_VERSION )
set(GINKGO_AMD_ARCH_FLAGS )

set(GINKGO_DPCPP_VERSION )
set(GINKGO_DPCPP_FLAGS )
set(GINKGO_MKL_ROOT )
set(GINKGO_DPL_ROOT )

set(GINKGO_BUILD_MPI ON)

set(GINKGO_HAVE_PAPI_SDE 0)

set(GINKGO_HAVE_HWLOC 0)

# Ginkgo installation configuration
set(GINKGO_CONFIG_FILE_PATH "${CMAKE_CURRENT_LIST_DIR}")
string(REPLACE "lib/cmake/Ginkgo" "" GINKGO_INSTALL_PREFIX "${GINKGO_CONFIG_FILE_PATH}")
set(GINKGO_INSTALL_INCLUDE_DIR "${GINKGO_INSTALL_PREFIX}/include")
set(GINKGO_INSTALL_LIBRARY_DIR "${GINKGO_INSTALL_PREFIX}/lib")
set(GINKGO_INSTALL_PKGCONFIG_DIR "${GINKGO_INSTALL_PREFIX}/lib/pkgconfig")
set(GINKGO_INSTALL_CONFIG_DIR "${GINKGO_INSTALL_PREFIX}/lib/cmake/Ginkgo")
set(GINKGO_INSTALL_MODULE_DIR "${GINKGO_INSTALL_PREFIX}/lib/cmake/Ginkgo/Modules")
set(GINKGO_INSTALL_RPATH_FOR_HIP "-Wl,-rpath,${GINKGO_INSTALL_LIBRARY_DIR}")
set(GINKGO_INSTALL_RPATH ${GINKGO_INSTALL_RPATH})
set(GINKGO_INSTALL_RPATH_USE_ORIGIN ${GINKGO_INSTALL_RPATH_USE_ORIGIN})
set(GINKGO_INSTALL_RPATH_DEPENDENCIES ${GINKGO_INSTALL_RPATH_DEPENDENCIES})

# Forward Ginkgo's MODULE PATH and the PREFIX PATH for HIP and more
list(APPEND CMAKE_MODULE_PATH "/opt/local/share/cmake/Modules;/opt/local/var/macports/build/_opt_PPCSnowLeopardPorts_math_ginkgo/ginkgo/work/ginkgo-1.5.0/cmake/Modules/" "${GINKGO_INSTALL_MODULE_DIR}")
list(APPEND CMAKE_PREFIX_PATH "/opt/local/share/cmake/Modules")


set(GINKGO_INTERFACE_LINK_LIBRARIES "ginkgo_device;ginkgo_omp;ginkgo_cuda;ginkgo_reference;ginkgo_hip;ginkgo_dpcpp;MPI::MPI_CXX")
set(GINKGO_INTERFACE_LINK_FLAGS "-L/opt/local/lib -lginkgo$<$<CONFIG:Debug>:d> -lginkgo_omp$<$<CONFIG:Debug>:d> -lginkgo_cuda$<$<CONFIG:Debug>:d> -lginkgo_reference$<$<CONFIG:Debug>:d> -lginkgo_hip$<$<CONFIG:Debug>:d> -lginkgo_dpcpp$<$<CONFIG:Debug>:d> -lginkgo_device$<$<CONFIG:Debug>:d>")
set(GINKGO_INTERFACE_CXX_FLAGS "-I/opt/local/include")

# CUDA
set(GINKGO_CUDA_COMPILER "")
set(GINKGO_CUDA_COMPILER_VERSION )
set(GINKGO_CUDA_HOST_LINK_LAUNCHER "")

set(GINKGO_CUBLAS_LIBRARIES )
set(GINKGO_CUSPARSE_LIBRARIES )
set(GINKGO_CUDA_LIBRARIES )
set(GINKGO_CUDA_TOOLKIT_INCLUDE_DIRECTORIES "")

set(GINKGO_CUDA_FLAGS "")
set(GINKGO_CUDA_FLAGS_DEBUG "")
set(GINKGO_CUDA_FLAGS_RELEASE "")

# OpenMP
set(GINKGO_OPENMP_VERSION 4.5)

set(GINKGO_OPENMP_LIB_NAMES gomp)
set(GINKGO_OPENMP_LIBRARIES /opt/local/lib/gcc12/libgomp.dylib)

set(GINKGO_OPENMP_FLAGS "-fopenmp")

# NOTE: we do not export benchmarks, examples, tests or devel tools
#     so `third_party` libraries are currently unneeded.

# propagate CUDA_HOST_COMPILER if needed
if (GINKGO_BUILD_CUDA OR (GINKGO_BUILD_HIP
    AND GINKGO_HIP_PLATFORM MATCHES "${GINKGO_HIP_PLATFORM_NVIDIA_REGEX}"))
    if (GINKGO_CUDA_HOST_COMPILER AND NOT CMAKE_CUDA_HOST_COMPILER
        AND EXISTS "${GINKGO_CUDA_HOST_COMPILER}")
        message(STATUS "Ginkgo: Setting CUDA host compiler to ${GINKGO_CUDA_HOST_COMPILER}")
        set(CMAKE_CUDA_HOST_COMPILER "${GINKGO_CUDA_HOST_COMPILER}" CACHE STRING "" FORCE)
    endif()
endif()

if(GINKGO_HAVE_PAPI_SDE)
    find_package(PAPI REQUIRED OPTIONAL_COMPONENTS sde)
endif()

if(GINKGO_HAVE_HWLOC)
    find_package(HWLOC REQUIRED)
endif()

# Check for MPI if it is enabled
if(GINKGO_BUILD_MPI)
    find_package(MPI REQUIRED)
endif()

# HIP and OpenMP depend on Threads::Threads in some circumstances, but don't find it
if (GINKGO_BUILD_HIP OR GINKGO_BUILD_OMP)
    find_package(Threads REQUIRED)
endif()

# Needed because of a known issue with CUDA while linking statically.
# For details, see https://gitlab.kitware.com/cmake/cmake/issues/18614
if((NOT GINKGO_BUILD_SHARED_LIBS) AND GINKGO_BUILD_CUDA)
    enable_language(CUDA)
endif()

if((NOT GINKGO_BUILD_SHARED_LIBS) AND GINKGO_BUILD_HIP)
    find_package(HIP REQUIRED)
    find_package(hipblas REQUIRED)
    find_package(hipfft) # optional
    find_package(hiprand REQUIRED)
    find_package(hipsparse REQUIRED)
    find_package(rocrand REQUIRED)
endif()

if((NOT GINKGO_BUILD_SHARED_LIBS) AND GINKGO_BUILD_DPCPP)
    find_package(MKL CONFIG REQUIRED HINTS "${GINKGO_MKL_ROOT}")
    find_package(oneDPL REQUIRED HINTS "${GINKGO_DPL_ROOT}")
endif()

include(${CMAKE_CURRENT_LIST_DIR}/GinkgoTargets.cmake)

==> ginkgo-1.6.0_1+gcc12+mpich.darwin_10.ppc.tbz2: opt/local/lib/cmake/Ginkgo/GinkgoConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was GinkgoConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(GINKGO_PROJECT_NAME "Ginkgo")
set(GINKGO_PROJECT_VERSION 1.6.0)
set(GINKGO_PROJECT_DESCRIPTION "A numerical linear algebra library targeting many-core architectures")

# Extra version information
set(GINKGO_VERSION_MAJOR 1)
set(GINKGO_VERSION_MINOR 6)
set(GINKGO_VERSION_PATCH 0)

# Git information
set(GINKGO_GIT_BRANCH "")
set(GINKGO_GIT_REVISION "")
set(GINKGO_GIT_SHORTREV "")

# CMake build configuration
set(GINKGO_BUILD_TYPE "Release")
set(GINKGO_BUILD_SHARED_LIBS "ON")
set(GINKGO_DEBUG_POSTFIX "d")

# Compiler configuration
set(GINKGO_CXX_COMPILER "/opt/local/bin/mpicxx-mpich-gcc12")
set(GINKGO_CXX_COMPILER_VERSION 12.3.0)

set(GINKGO_CXX_FLAGS "-pipe -Os -DNDEBUG -I/opt/local/include -D_GLIBCXX_USE_CXX11_ABI=0")
set(GINKGO_CXX_FLAGS_DEBUG "-g")
set(GINKGO_CXX_FLAGS_RELEASE "-O3 -DNDEBUG")

set(GINKGO_EXE_LINKER_FLAGS "-L/opt/local/lib -Wl,-headerpad_max_install_names -latomic -Wl,-rpath,/opt/local/lib/libgcc")
set(GINKGO_EXE_LINKER_FLAGS_DEBUG "")
set(GINKGO_EXE_LINKER_FLAGS_RELEASE "")

# Ginkgo configuration
set(GINKGO_BUILD_REFERENCE ON)
set(GINKGO_BUILD_OMP OFF)
set(GINKGO_BUILD_CUDA OFF)
set(GINKGO_BUILD_HIP OFF)
set(GINKGO_BUILD_MPI ON)
set(GINKGO_BUILD_DPCPP OFF)

set(GINKGO_DEVEL_TOOLS OFF)
set(GINKGO_BUILD_TESTS OFF)
set(GINKGO_BUILD_EXAMPLES OFF)
set(GINKGO_BUILD_EXTLIB_EXAMPLE )
set(GINKGO_BUILD_BENCHMARKS OFF)

set(GINKGO_BUILD_DOC OFF)
set(GINKGO_DOC_GENERATE_EXAMPLES OFF)
set(GINKGO_DOC_GENERATE_PDF OFF)
set(GINKGO_DOC_GENERATE_DEV )

set(GINKGO_SKIP_DEPENDENCY_UPDATE ON)
set(GINKGO_EXPORT_BUILD_DIR OFF)
set(GINKGO_VERBOSE_LEVEL 1)

set(GINKGO_WITH_CLANG_TIDY OFF)
set(GINKGO_WITH_IWYU OFF)
set(GINKGO_CLANG_TIDY_PATH )
set(GINKGO_IWYU_PATH )

set(GINKGO_JACOBI_FULL_OPTIMIZATIONS OFF)

set(GINKGO_CUDA_ARCHITECTURES Auto)
set(GINKGO_CUDA_DEFAULT_HOST_COMPILER OFF)
set(GINKGO_CUDA_HOST_COMPILER )
set(GINKGO_CUDA_ARCH_FLAGS )

set(GINKGO_HIP_COMPILER_FLAGS )
set(GINKGO_HIP_HCC_COMPILER_FLAGS )
set(GINKGO_HIP_NVCC_COMPILER_FLAGS )
set(GINKGO_HIP_CLANG_COMPILER_FLAGS )
set(GINKGO_HIP_PLATFORM )
set(GINKGO_HIP_PLATFORM_AMD_REGEX )
set(GINKGO_HIP_PLATFORM_NVIDIA_REGEX )
set(GINKGO_HIP_AMDGPU )
set(GINKGO_HIP_VERSION )
set(GINKGO_AMD_ARCH_FLAGS )

set(GINKGO_DPCPP_VERSION )
set(GINKGO_DPCPP_MAJOR_VERSION 0)
set(GINKGO_DPCPP_FLAGS )
set(GINKGO_MKL_ROOT )
set(GINKGO_DPL_ROOT )

set(GINKGO_BUILD_MPI ON)

set(GINKGO_HAVE_PAPI_SDE 0)

set(GINKGO_HAVE_HWLOC 0)

set(GINKGO_HAVE_ROCTX 0)

# Ginkgo installation configuration
set(GINKGO_INSTALL_PREFIX "${PACKAGE_PREFIX_DIR}")
set(GINKGO_INSTALL_INCLUDE_DIR "${PACKAGE_PREFIX_DIR}/include")
set(GINKGO_INSTALL_LIBRARY_DIR "${PACKAGE_PREFIX_DIR}/lib")
set(GINKGO_INSTALL_RPATH_FOR_HIP "-Wl,-rpath,${GINKGO_INSTALL_LIBRARY_DIR}")
set(GINKGO_INSTALL_RPATH ON)
set(GINKGO_INSTALL_RPATH_USE_ORIGIN )
set(GINKGO_INSTALL_RPATH_DEPENDENCIES OFF)

# Forward Ginkgo's MODULE PATH and the PREFIX PATH for HIP and more
list(APPEND CMAKE_MODULE_PATH "${PACKAGE_PREFIX_DIR}/lib/cmake/Ginkgo/Modules")
if(GINKGO_BUILD_HIP)
    list(APPEND CMAKE_MODULE_PATH "")
endif()
list(APPEND CMAKE_PREFIX_PATH "${GINKGO_INSTALL_PREFIX}")


set(GINKGO_INTERFACE_LINK_LIBRARIES "ginkgo_device;ginkgo_omp;ginkgo_cuda;ginkgo_reference;ginkgo_hip;ginkgo_dpcpp;MPI::MPI_CXX")
set(GINKGO_INTERFACE_LINK_FLAGS "-L/opt/local/lib -lginkgo$<$<CONFIG:Debug>:d> -lginkgo_omp$<$<CONFIG:Debug>:d> -lginkgo_cuda$<$<CONFIG:Debug>:d> -lginkgo_reference$<$<CONFIG:Debug>:d> -lginkgo_hip$<$<CONFIG:Debug>:d> -lginkgo_dpcpp$<$<CONFIG:Debug>:d> -lginkgo_device$<$<CONFIG:Debug>:d>")
set(GINKGO_INTERFACE_CXX_FLAGS "-I/opt/local/include")

# CUDA
set(GINKGO_CUDA_COMPILER "")
set(GINKGO_CUDA_COMPILER_VERSION )
set(GINKGO_CUDA_HOST_LINK_LAUNCHER "")

set(GINKGO_CUBLAS_LIBRARIES )
set(GINKGO_CUSPARSE_LIBRARIES )
set(GINKGO_CUDA_LIBRARIES )
set(GINKGO_CUDA_TOOLKIT_INCLUDE_DIRECTORIES "")

set(GINKGO_CUDA_FLAGS "")
set(GINKGO_CUDA_FLAGS_DEBUG "")
set(GINKGO_CUDA_FLAGS_RELEASE "")

# OpenMP
set(GINKGO_OPENMP_VERSION )

set(GINKGO_OPENMP_LIB_NAMES )
set(GINKGO_OPENMP_LIBRARIES )

set(GINKGO_OPENMP_FLAGS "")

set(GINKGO_HAVE_TAU "0")
set(GINKGO_HAVE_VTUNE "0")
set(GINKGO_HAVE_METIS "1")
set(VTune_PATH "/..")

# NOTE: we do not export benchmarks, examples, tests or devel tools
#     so `third_party` libraries are currently unneeded.

# propagate CUDA_HOST_COMPILER if needed
if (GINKGO_BUILD_CUDA OR (GINKGO_BUILD_HIP
    AND GINKGO_HIP_PLATFORM MATCHES "${GINKGO_HIP_PLATFORM_NVIDIA_REGEX}"))
    if (GINKGO_CUDA_HOST_COMPILER AND NOT CMAKE_CUDA_HOST_COMPILER
        AND EXISTS "${GINKGO_CUDA_HOST_COMPILER}")
        message(STATUS "Ginkgo: Setting CUDA host compiler to ${GINKGO_CUDA_HOST_COMPILER}")
        set(CMAKE_CUDA_HOST_COMPILER "${GINKGO_CUDA_HOST_COMPILER}" CACHE STRING "" FORCE)
    endif()
endif()

if(GINKGO_HAVE_PAPI_SDE)
    find_package(PAPI REQUIRED OPTIONAL_COMPONENTS sde)
endif()

if(GINKGO_HAVE_HWLOC)
    find_package(HWLOC REQUIRED)
endif()

# Check for MPI if it is enabled
if(GINKGO_BUILD_MPI)
    find_package(MPI 3.1 COMPONENTS CXX REQUIRED)
endif()

# HIP and OpenMP depend on Threads::Threads in some circumstances, but don't find it
if (GINKGO_BUILD_HIP OR GINKGO_BUILD_OMP)
    find_package(Threads REQUIRED)
endif()

# Needed because of a known issue with CUDA while linking statically.
# For details, see https://gitlab.kitware.com/cmake/cmake/issues/18614
if((NOT GINKGO_BUILD_SHARED_LIBS) AND GINKGO_BUILD_CUDA)
    enable_language(CUDA)
    find_package(NVTX REQUIRED)
endif()

if((NOT GINKGO_BUILD_SHARED_LIBS) AND GINKGO_BUILD_HIP)
    find_package(HIP REQUIRED)
    find_package(hipblas REQUIRED)
    find_package(hipfft) # optional
    find_package(hiprand REQUIRED)
    find_package(hipsparse REQUIRED)
    find_package(rocrand REQUIRED)
    set(ROCTRACER_PATH "")
    if(GINKGO_HAVE_ROCTX)
        find_package(ROCTX REQUIRED)
    endif()
endif()

if((NOT GINKGO_BUILD_SHARED_LIBS) AND GINKGO_BUILD_DPCPP)
    find_package(MKL CONFIG REQUIRED HINTS "${GINKGO_MKL_ROOT}")
    find_package(oneDPL REQUIRED HINTS "${GINKGO_DPL_ROOT}")
endif()

if(GINKGO_HAVE_VTUNE)
    find_package(VTune REQUIRED)
endif()

if((NOT GINKGO_BUILD_SHARED_LIBS) AND GINKGO_HAVE_METIS)
    find_package(METIS REQUIRED)
endif()

if((NOT GINKGO_BUILD_SHARED_LIBS) AND GINKGO_HAVE_TAU)
    find_package(PerfStubs REQUIRED)
endif()

include(${CMAKE_CURRENT_LIST_DIR}/GinkgoTargets.cmake)
